---
title: "Benchmarks"
icon: "material/chart-bar"
---

# Benchmarks

The COOM suite includes various scalable benchmark sets.
More information can be found in the [COOM Benchmarks repository][benchmarks].

[benchmarks]: https://github.com/potassco/coom-benchmarks
